@@ -6,7 +6,7 @@ import numpy
 from dabax.common_tools import calculate_f0_from_f0coeff, atomic_number, atomic_symbols
 
 try: import xraylib
-except: print("xraylib is not available.")
+except: pass
 
 from dabax.dabax_xraylib import DabaxXraylib
 
